@@ -1243,9 +1243,10 @@ write_mtab_entry(const dav_args *args)
     if (args->use_utab) {
         if (asprintf(&utab_line,
                      "SRC=%s TARGET=%s ROOT=/ "
-                     "OPTS=uid=%i,gid=%i%s%s%s,helper=%s\n",
+                     "OPTS=uid=%i,gid=%i%s%s%s%s,helper=%s\n",
                      url, mpoint, args->uid, args->gid,
                      (args->grpid) ? ",grpid" : "",
+                     (args->netdev) ? ",_netdev" : "",
                      (!privileged) ? ",user=" : "",
                      (!privileged) ? uid_name : "",
                      DAV_FS_TYPE) < 0)
@@ -1508,7 +1509,7 @@ delete_args(dav_args *args)
 
 
 /* Parses the string option and stores the values in the appropriate fields of
-   args. If an unknown option is found exit(EXIT_FAILURE) is called.
+   args.
    All strings returned in args are newly allocated, and the calling function
    is responsible to free them.
    option : a comma separated list of options (like the options in fstab and
@@ -1540,12 +1541,6 @@ get_options(dav_args *args, char *option)
         NOEXEC,
         DEV,
         NODEV,
-        ASYNC,
-        AUTO,
-        NOAUTO,
-        COMMENT,
-        NOFAIL,
-        DEFAULTS,
         END
     };
     char *suboptions[] = {
@@ -1570,12 +1565,6 @@ get_options(dav_args *args, char *option)
         [NOEXEC] = "noexec",
         [DEV] = "dev",
         [NODEV] = "nodev",
-        [ASYNC] = "async",
-        [AUTO] = "auto",
-        [NOAUTO] = "noauto",
-        [COMMENT] = "comment",
-        [NOFAIL] = "nofail",
-        [DEFAULTS] = "defaults",
         [END] = NULL
     };
 
@@ -1667,19 +1656,8 @@ get_options(dav_args *args, char *option)
         case NODEV:
             args->mopts |= MS_NODEV;
             break;
-        case ASYNC:
-        case AUTO:
-        case NOAUTO:
-        case COMMENT:
-        case NOFAIL:
-        case DEFAULTS:
-            break;
         default:
-            if (so == -1) {
-                printf(_("Unknown option %s.\n"), argument);
-                usage();
-                exit(EXIT_FAILURE);
-            }
+            break;
         }
     }
 }
